@@ -28,11 +28,11 @@ Net::PJLink - PJLink protocol implementation
 
 =head1 VERSION
 
-Version 1.02
+Version 1.03
 
 =cut
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 
 =head1 SYNOPSIS
@@ -525,8 +525,8 @@ sub _send_command {
 				$cnx->close;
 				$self->{'host'}->{$host} = 0;
 			}
-			$cmd = $COMMAND{$cmd};
-			if (defined $resp && $resp =~ /^%1$cmd=(.*)\x0d$/) {
+			my $cmd_symbol = $COMMAND{$cmd};
+			if (defined $resp && $resp =~ /^%1$cmd_symbol=(.*)\x0d$/) {
 				if (defined $RESPONSE{$1}) {
 					$result{$host} = $RESPONSE{$1};
 				} else {
@@ -1018,7 +1018,7 @@ L<http://search.cpan.org/dist/Net-PJLink/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 Kyle Emmons.
+Copyright 2017 Kyle Emmons.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
